@@ -223,20 +223,37 @@ vec4f ConfEntry::getVec4() {
 //ConfSection
 
 ConfSection::ConfSection() {
+    lineno = 0;
+    conf   = 0;
 }
 
-ConfSection::ConfSection(const std::string& name) {
-    this->name = name;
+ConfSection::ConfSection(const std::string& name, int lineno) {
+    this->name   = name;
+    this->lineno = lineno;
+    this->conf   = 0;
 }
 
 ConfSection::~ConfSection() {
     clear();
 }
 
+
 std::string ConfSection::getName() {
     return name;
 }
 
+ConfFile* ConfSection::getConfFile() {
+    return conf;
+}
+
+void ConfSection::setConfFile(ConfFile* conf) {
+    this->conf = conf;
+}
+
+int ConfSection::getLineNumber() {
+    return lineno;
+}
+
 ConfEntryList* ConfSection::getEntries(const std::string& key) {
     std::map<std::string, ConfEntryList*>::iterator entry_finder = entrymap.find(key);
 
@@ -510,7 +527,7 @@ void ConfFile::load() {
 
             if(sec != 0) addSection(sec);
 
-            sec = new ConfSection(matches[0]);
+            sec = new ConfSection(matches[0], lineno);
 
         // key value pairs
         } else if(ConfFile_key_value.match(line, &matches)) {
@@ -526,7 +543,7 @@ void ConfFile::load() {
                 else if(string_end != value.size()-1) value = value.substr(0,string_end+1);
             }
 
-            if(sec==0) sec = new ConfSection("");
+            if(sec==0) sec = new ConfSection("", lineno);
 
             sec->addEntry(key, value, lineno);
 
@@ -583,6 +600,13 @@ bool ConfFile::hasSection(const std::string& section) {
     return true;
 }
 
+ConfSection* ConfFile::addSection(const std::string& section) {
+    ConfSection* sec = new ConfSection(section);
+    addSection(sec);
+
+    return sec;
+}
+
 void ConfFile::addSection(ConfSection* section) {
 
     ConfSectionList* sectionlist = getSections(section->getName());
@@ -591,6 +615,7 @@ void ConfFile::addSection(ConfSection* section) {
         sectionmap[section->getName()] = sectionlist = new ConfSectionList;
     }
 
+    section->setConfFile(this);
     sectionlist->push_back(section);
 }
 
@@ -636,8 +661,7 @@ void ConfFile::setEntry(const std::string& section, const std::string& key, cons
     ConfSection* sec = getSection(section);
 
     if(sec==0) {
-        sec = new ConfSection(section);
-        addSection(sec);
+        sec = addSection(section);
     }
 
     sec->setEntry(key, value);
@@ -717,29 +741,67 @@ vec4f ConfFile::getVec4(const std::string& section, const std::string& key) {
 }
 
 void ConfFile::unknownOptionException(ConfEntry* entry) {
-    std::string reason = "unknown option ";
+    std::string reason = "unknown option '";
     reason += entry->getName();
+    reason += std::string("'");
 
     entryException(entry, reason);
 }
 
 void ConfFile::missingValueException(ConfEntry* entry) {
 
-    std::string reason = std::string("no value specified for ");
+    std::string reason = std::string("no value specified for '");
     reason += entry->getName();
+    reason += std::string("'");
 
     entryException(entry, reason);
 }
 
 void ConfFile::invalidValueException(ConfEntry* entry) {
 
-    std::string reason = std::string("invalid ");
+    std::string reason = std::string("invalid '");
     reason += entry->getName();
-    reason += std::string(" value");
+    reason += std::string("' value");
 
     entryException(entry, reason);
 }
 
+void ConfFile::missingEntryException(ConfSection* section, std::string entryname) {
+    std::string reason = std::string("section '");
+    reason += section->getName();
+    reason += std::string("' missing required entry '");
+    reason += entryname;
+    reason += std::string("'");
+
+    sectionException(section, reason);
+}
+
+void ConfFile::sectionException(ConfSection* section, std::string reason) {
+
+    std::string errmsg;
+
+    int lineno = 0;
+
+    if(conffile.size()) {
+        errmsg = conffile;
+
+        if(section != 0 && section->getLineNumber() != 0) {
+            lineno = section->getLineNumber();
+
+            char linebuff[256];
+            snprintf(linebuff, 256, ", line %d", lineno);
+
+            errmsg += std::string(linebuff);
+        }
+
+        errmsg += std::string(": ");
+    }
+
+    errmsg += reason;
+
+    throw ConfFileException(errmsg, conffile, lineno);
+}
+
 void ConfFile::entryException(ConfEntry* entry, std::string reason) {
 
     std::string errmsg;
