@@ -23,6 +23,8 @@
 #include "core/quadtree.h"
 #include "core/pi.h"
 
+#include "gource_settings.h"
+
 #include "spline.h"
 #include "file.h"
 
@@ -63,31 +65,30 @@ class RDirNode : public QuadItem {
     float since_last_file_change;
     float since_last_node_change;
 
-
     float file_area;
     float dir_radius;
     float dir_radius_sqrt;
+    float parent_radius;
 
     int depth;
 
     int visible_count;
 
-    void calcArea();
+    vec3f screenpos;
+    vec2f node_normal;
+
     void calcRadius();
     void calcColour();
 
-    std::string commonPathPrefix(std::string& str);
+    std::string commonPathPrefix(const std::string& str) const;
 
-    vec2f node_normal;
-
-    void changePath(std::string abspath);
+    void changePath(const std::string & abspath);
 
     void calcProjectedPos();
 
     void setInitialPosition();
 
-    void drawBeam(vec2f pos_src, vec4f col_src, vec2f pos_dest, vec4f col_dest, float beam_radius);
-    void drawEdge(RDirNode* child);
+    void drawEdge(RDirNode* child) const;
     void updateSpline(float dt);
     void move(float dt);
 
@@ -95,14 +96,16 @@ class RDirNode : public QuadItem {
     void updateFilePositions();
 
     void adjustPath();
-    void drawDirName(FXFont& dirfont);
+    void drawDirName(const FXFont& dirfont) const;
 public:
-    RDirNode(RDirNode* parent, std::string abspath);
+    RDirNode(RDirNode* parent, const std::string & abspath);
     ~RDirNode();
 
-    bool empty();
+    void printFiles();
+    
+    bool empty() const;
 
-    bool isAnchor(RDirNode* node);
+    bool isAnchor(RDirNode* node) const;
 
     RDirNode* getRoot();
 
@@ -112,79 +115,119 @@ public:
     void addVisible();
     bool isVisible();
 
-    float getArea();
+    float getArea() const;
 
-    int totalDirCount();
-    int totalFileCount();
+    int totalDirCount() const;
+    int totalFileCount() const;
 
-    int getTokenOffset();
+    int getTokenOffset() const;
 
-    int dirCount();
-    int fileCount();
-    int visibleFileCount();
+    int dirCount() const;
+    int fileCount() const;
+    int visibleFileCount() const;
+    bool noDirs() const;
+    bool noFiles() const;
 
-    bool prefixedBy(std::string path);
+    bool prefixedBy(const std::string & path) const;
 
-    std::string getPath();
+    const std::string & getPath() const;
 
-    vec2f getNodeNormal();
+    const vec2f & getNodeNormal() const;
 
-    bool isParentOf(RDirNode* node);
+    bool isParent(RDirNode* node) const;
 
     bool addFile(RFile* f);
     bool removeFile(RFile* f);
 
-    int getDepth();
+    int getDepth() const;
 
-    std::list<RDirNode*>* getChildren();
+    const std::list<RDirNode*> & getChildren() const;
 
     void updateQuadItemBounds();
 
-    float getRadius();
-    float getRadiusSqrt();
+    float getParentRadius() const;
+    float getRadius() const;
+    float getRadiusSqrt() const;
 
-    vec3f averageFileColour();
+    vec3f averageFileColour() const;
 
-    vec4f getColour();
+    const vec4f & getColour() const;
 
-    RDirNode* getParent();
+    RDirNode* getParent() const;
 
-    vec2f getPos();
+    const vec2f & getPos() const;
 
     void calcEdges();
 
-    vec2f getProjectedPos();
-    vec2f getSPos();
+    const vec2f & getProjectedPos() const;
+    const vec2f & getSPos() const;
 
-    void setPos(vec2f pos);
+    void setPos(const vec2f & pos);
 
     void rotate(float s, float c);
 
     void setParent(RDirNode* parent);
 
-    float distanceTo(RDirNode* node);
+    float distanceToParent() const;
 
     void addNode(RDirNode* node);
 
-    void debug(int indent=0);
+    void debug(int indent=0) const;
 
     void applyForceDir(RDirNode* dir);
-
     void applyForces(QuadTree &quadtree);
 
     void logic(float dt);
 
-    void drawEdges(float dt);
-    void drawEdgeShadows(float dt);
+    void drawEdges(float dt) const;
+    void drawEdgeShadows(float dt) const;
 
-    void drawBloom(Frustum& frustum, float dt);
+    void drawBloom(const Frustum & frustum, float dt);
 
-    void drawShadows(Frustum& frustum, float dt);
-    void drawFiles(Frustum& frustum, float dt);
-    void drawSimple(Frustum& frustum, float dt);
-    void drawNames(FXFont& dirfont, Frustum& frustum);
+    void drawShadows(const Frustum & frustum, float dt) const;
+    void drawFiles(const Frustum & frustum, float dt) const;
+    void drawSimple(const Frustum & frustum, float dt) const;
+
+    void calcScreenPos();
+
+    void drawNames(const FXFont & dirfont, const Frustum & frustum);
+
+    void nodeCount() const;
+};
+
+class DirForceFunctor : public VisitFunctor<QuadItem>{
+  private:
+    RDirNode * this_dir;
+    std::set<RDirNode*> seen;
+    size_t loopCount;
+
+  public:
+    DirForceFunctor(RDirNode * dir) : this_dir(dir), seen(), loopCount(0){}
+    int getLoopCount() const{ return loopCount; }
+    void operator()(QuadItem * item){
+
+        std::set<RDirNode*>::iterator seentest;
+        RDirNode* d = (RDirNode*) (item);
+
+        if(d==this_dir) return;
+        if(d==this_dir->getParent()) return;
+        if(d->getParent() == this_dir) return;
+        if(this_dir->isParent(d)) return;
+        if(d->isParent(this_dir)) return;
+
+        if(d->node_count != 1) {
+            if((seentest = seen.find(d)) != seen.end())
+                return;
+
+            seen.insert(d);
+        }
+
+        this_dir->applyForceDir(d);
+
+        loopCount++;
+
+    }
 
-    void nodeCount();
 };
 
 extern int gGourceDirNodeInnerLoops;
@@ -194,11 +237,6 @@ extern float gGourcePointSize;
 extern bool  gGourceNodeDebug;
 extern bool  gGourceGravity;
 extern float gGourceForceGravity;
-extern bool  gGourceDrawDirName;
-
-extern float gGourceBloomMultiplier;
-extern float gGourceBloomIntensity;
-extern float gGourceElasticity;
 
 extern std::map<std::string, RDirNode*> gGourceDirMap;
 
