@@ -29,6 +29,10 @@ Gource::Gource(FrameExporter* exporter) {
 
     commitlog = 0;
 
+    if(!gGourceSettings.file_graphic) {
+        gGourceSettings.file_graphic = texturemanager.grab("file.png");
+    }
+
     fontlarge = fontmanager.grab("FreeSans.ttf", 42);
     fontlarge.dropShadow(true);
     fontlarge.roundCoordinates(true);
@@ -98,7 +102,8 @@ Gource::Gource(FrameExporter* exporter) {
     date_x_offset = 0;
 
     camera = ZoomCamera(vec3f(0,0, -300), vec3f(0.0, 0.0, 0.0), 250.0, 5000.0);
-
+    camera.setPadding(gGourceSettings.padding);
+    
     setCameraMode(gGourceSettings.camera_mode);
 
     root = 0;
@@ -117,7 +122,7 @@ Gource::Gource(FrameExporter* exporter) {
     if(exporter==0 && gGourceSettings.repo_count==1) slider.show();
 }
 
-RCommitLog* Gource::determineFormat(std::string logfile) {
+RCommitLog* Gource::determineFormat(const std::string& logfile) {
     debugLog("determineFormat(%s)\n", logfile.c_str());
 
     RCommitLog* clog = 0;
@@ -752,6 +757,7 @@ void Gource::reset() {
     hoverFile = 0;
 
     manual_rotate = false;
+    rotation_remaining_angle = 0.0f;
 
     selectedUser = 0;
     hoverUser = 0;
@@ -1057,7 +1063,6 @@ void Gource::interactUsers() {
     for(std::map<std::string,RUser*>::iterator it = users.begin(); it!=users.end(); it++) {
         RUser* user = it->second;
 
-        user->updateQuadItemBounds();
         userTree->addItem(user);
     }
 
@@ -1081,10 +1086,11 @@ void Gource::updateBounds() {
     user_bounds.reset();
 
     for(std::map<std::string,RUser*>::iterator it = users.begin(); it!=users.end(); it++) {
-        RUser* u = it->second;
+        RUser* user = it->second;
 
-        if(!u->isIdle()) {
-            user_bounds.update(u->getPos());
+        if(!user->isIdle()) {
+            user->updateQuadItemBounds();
+            user_bounds.update(user->quadItemBounds);
         }
     }
 
@@ -1094,7 +1100,8 @@ void Gource::updateBounds() {
         RDirNode* node = it->second;
 
         if(node->isVisible()) {
-            dir_bounds.update(node->getPos());
+            node->updateQuadItemBounds();
+            dir_bounds.update(node->quadItemBounds);
         }
     }
 }
@@ -1105,9 +1112,6 @@ void Gource::updateUsers(float t, float dt) {
 
     size_t idle_users = 0;
 
-    //recalc the user bounds
-    user_bounds.reset();
-
     // move users
     for(std::map<std::string,RUser*>::iterator it = users.begin(); it!=users.end(); it++) {
         RUser* u = it->second;
@@ -1156,7 +1160,7 @@ void Gource::updateUsers(float t, float dt) {
     }
 }
 
-void Gource::updateQuadTree() {
+void Gource::interactDirs() {
 
     // update quad tree
     Bounds2D quadtreebounds = dir_bounds;
@@ -1182,7 +1186,6 @@ void Gource::updateQuadTree() {
         RDirNode* node = it->second;
 
         if(!node->empty()) {
-            node->updateQuadItemBounds();
             dirNodeTree->addItem(node);
         }
     }
@@ -1251,19 +1254,26 @@ void Gource::updateCamera(float dt) {
     //automatically rotate camera
     if(auto_rotate) {
 
-        float dratio = 0.95f;
+        if(rotation_remaining_angle > 0.0f) {
 
-        bool rightmouse = cursor.rightButtonPressed();
+            //rotation through 90 degrees, speed peaks at half way
+            float angle_rate = std::max(dt, (float) (1.0f - fabs((rotation_remaining_angle / 90.0f) - 0.5) * 2.0f)) * dt;
 
-        if(!rightmouse && dir_bounds.area() > 10000.0f) {
+            rotate_angle = std::min(rotation_remaining_angle, 90.0f * angle_rate);
+            rotation_remaining_angle -= rotate_angle;
+
+            rotate_angle *= DEGREES_TO_RADIANS;
+
+        } else if(!cursor.rightButtonPressed() && dir_bounds.area() > 10000.0f) {
 
             float ratio = dir_bounds.width() / dir_bounds.height();
 
-            if(ratio<dratio) {
-                //rotate up to 90 degrees a second
-                rotate_angle = 90.0f * (dratio-ratio) * dt * DEGREES_TO_RADIANS;
+            if(ratio < 0.67f) {
+                rotation_remaining_angle = 90.0f;
             }
         }
+    } else {
+        rotation_remaining_angle = 0.0f;
     }
 }
 
@@ -1329,7 +1339,7 @@ void Gource::logic(float t, float dt) {
     //still want to update camera while paused
     if(paused) {
         updateBounds();
-        updateQuadTree();
+        interactDirs();
         updateCamera(dt);
         return;
     }
@@ -1398,11 +1408,12 @@ void Gource::logic(float t, float dt) {
     gGourceDirNodeInnerLoops = 0;
     gGourceFileInnerLoops = 0;
 
+    updateBounds();
+
     interactUsers();
     updateUsers(t, dt);
 
-    updateQuadTree();
-    updateBounds();
+    interactDirs();
     updateDirs(dt);
 
     updateCamera(dt);
@@ -1817,6 +1828,7 @@ void Gource::draw(float t, float dt) {
 
     if(debug) {
         glDisable(GL_TEXTURE_2D);
+        glLineWidth(2.0);
         glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
 
         track_users ? user_bounds.draw() : dir_bounds.draw();
@@ -1944,6 +1956,7 @@ void Gource::draw(float t, float dt) {
         font.print(1,320,"User Inner Loops: %d", gGourceUserInnerLoops);
         font.print(1,340,"Dir Inner Loops: %d (QTree items = %d, nodes = %d)", gGourceDirNodeInnerLoops,
             dirNodeTree->item_count, dirNodeTree->node_count);
+        font.print(1,360,"Dir Bounds Ratio: %.2f, %.5f", dir_bounds.width() / dir_bounds.height(), rotation_remaining_angle);
 
         if(selectedUser != 0) {
 
