@@ -65,6 +65,7 @@ class Gource : public SDLApp {
     bool debug, trace_debug;
 
     bool manual_rotate;
+    float rotation_remaining_angle;
 
     MouseCursor cursor;
 
@@ -171,14 +172,16 @@ class Gource : public SDLApp {
 
     void toggleCameraMode();
 
-    RCommitLog* determineFormat(std::string logfile);
+    RCommitLog* determineFormat(const std::string& logfile);
 
-    void interactUsers();
+    void updateCamera(float dt);
 
     void updateUsers(float t, float dt);
     void updateDirs(float dt);
-    void updateCamera(float dt);
-    void updateQuadTree();
+
+    void interactUsers();
+    void interactDirs();
+
     void updateBounds();
 
     void updateTime(time_t display_time);
