@@ -32,7 +32,8 @@ class RAction;
 class RFile;
 
 class RUser : public Pawn {
-    void assignIcon();
+
+    void assignUserImage();
 
     std::list<RAction*> actions;
     std::list<RAction*> activeActions;
@@ -57,7 +58,7 @@ class RUser : public Pawn {
     const vec3f& getNameColour() const;
     void drawNameText(float alpha) const;
 public:
-    RUser(std::string name, vec2f pos, int tagid);
+    RUser(const std::string& name, vec2f pos, int tagid);
 
     vec3f getColour() const;
 
